pub enum TunnelState {
Open,
Closed,
Died,
}Expand description
The state of a single tunnel opened by the server.
Variants
Open
The tunnel is currently opene.
Closed
The tunnel was opened but then was manually closed.
Died
The tunnel was opened but died unexpectedly.
This may be due to something like a connection drop or the user killing the associated SSH process outside of the server’s knowledge.