pub enum OpenResult {
Success,
AlreadyOpen,
}Expand description
Possible outcomes of the “Open” command.
Besides these outcomes, an error may be signal by the return of a textual error message.
Variants
Success
Indicates that the tunnel was successfully opened.
AlreadyOpen
Indicates that nothing was done because a tunnel to the specified host was already open.